Check if the file provided is a xlsx standardised file
Exemples
check_standard_file(trial_file = system.file("extdata","standard_exemple.xlsx",package="startbox"))
#> [1] TRUE
Check if the file provided is a xlsx standardised file
check_standard_file(trial_file = system.file("extdata","standard_exemple.xlsx",package="startbox"))
#> [1] TRUE