Passer au contenu

This function imports meteorological data from a CSV file exported from the Topvigne App. The data are standardized before being added to self$obsdata. The function also updates the internal log (traceability).

Utilisation

import_topvigne_csv(self, filepath, obs_name = NULL, overwrite = FALSE)

Arguments

self

An user_data R6 object in which to import the meteo

filepath

File path of the csv file to be imported. This file must be a csv file exported from TopVigne (IFV app)

obs_name

the name of the observation to add

overwrite

Logical. If TRUE, replaces an existing entry with the same name.

Valeur de retour

Updates self$obs_data with the imported data, update also the log. Returns invisible(self$obs_data).

Exemples

if (FALSE) { # \dontrun{
# Import new topvigne data into an existing user_data object
file_path <- system.file("extdata","maladie_teisso_2024_11h12min_F1_17.06.csv",package="startbox")
import_topvigne_csv(self = mydata, filepath = file_path, obs_name = "F1")
} # }