This function analyzes the meteo_datetime column from the meteo slot
of the user_data object and determines if the data are daily or hourly observations.
It is mainly used by plot_meteo() to ensure that daily data are plotted correctly.
This function analyzes the meteo_datetime column from the meteo slot
of the user_data object and determines if the data are daily or hourly observations.
It is mainly used by plot_meteo() to ensure that daily data are plotted correctly.